Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Metrics ¶
Metrics returns a expvar.Func which implements Var by calling the function and formatting the returned value using JSON. Use this function when you need control of the measurement name for a data point.
package main
import (
"expvar"
"github.com/tevjef/go-runtime-metrics/influxdb"
)
func main {
expvar.Publish(os.Args[0], influxdb.Metrics("my-measurement-name"))
}
Types ¶
Click to show internal directories.
Click to hide internal directories.